.. module:: enaml.stdlib.message_box

========================
enaml.stdlib.message_box
========================

.. rubric:: Functions

.. autosummary::
    :nosignatures:

    about
    critical
    information
    question
    warning


.. rubric:: Classes

.. autosummary::
    :nosignatures:

    MessageBox


.. autofunction:: about

.. autofunction:: critical

.. autofunction:: information

.. autofunction:: question

.. autofunction:: warning

.. autoclass:: MessageBox
